[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/)
[![codecov](https://codecov.io/gh/The-Pyoneers/cs107-FinalProject/branch/master/graph/badge.svg?token=39UVNMQOKM)](undefined)
[![Build Status](https://travis-ci.com/The-Pyoneers/cs107-FinalProject.svg?token=Z9452YnmcP3jWAp8j3PV&branch=master)](https://travis-ci.com/The-Pyoneers/cs107-FinalProject)
[![CodeFactor](https://www.codefactor.io/repository/github/the-pyoneers/cs107-finalproject/badge?s=77ef071f20ab3df40d005769dc667aad2a60495e)](https://www.codefactor.io/repository/github/the-pyoneers/cs107-finalproject)
[![MIT license](https://img.shields.io/badge/License-MIT-blue.svg)](https://lbesson.mit-license.org/)
[![Documentation Status](https://readthedocs.org/projects/farad/badge/?version=latest)](https://farad.readthedocs.io/en/latest/?badge=latest)

# CS107 Final Project - Group #34

This repository contains related to project group #34's final project for CS107/AC207.

## Group Members

|      **Name**        |       **Email Address**       |
| -------------------- | ----------------------------- |
| Matthew Stewart      | matthew_stewart@g.harvard.edu |
| Xiaolan Ke           | xiaolan_ke@g.harvard.edu      |
| ChunChao Tseng       | cht039@g.harvard.edu          |
| Zeyuan Hu            | zeyuan_hu@fas.harvard.edu     |

## Documentation

The documentation for this package can be found [here](https://farad.readthedocs.io/en/latest/index.html#).
